/*jslint node:true, nomen:true*/

(function () {
    'use strict';

    var ArgParser = require('argparse').ArgumentParser,
        cfg = require('./cfg'),
        _ = require('underscore'),
        parser = new ArgParser({
            version: '0.17.4',
            addHelp: true,
            description: 'ePages 6 node.js helper'
        }),
        subparsers = parser.addSubparsers({
            title: 'subcommands',
            dest: 'subcommand'
        }),
        modules = {};

    // Add some logging options for the main parser
    parser.addArgument(
        ['-l', '--extended-log'],
        {
            nargs: 0,
            required: false,
            help: 'Activate extended logging and stack tracing'
        }
    );

    // Construct the subparsers corresponding to config
    _.each(cfg, function (subparser, id) {
        var currentSubParser = subparsers.addParser(id, { 'addHelp': true, 'description': subparser.description, 'epilog': subparser.example });

        // make modules available for cli
        modules[id] = subparser.exec;

        // Add arguments to subparsers
        _.each(subparser.args, function (argument) {
            currentSubParser.addArgument(argument.alias, {
                'nargs': argument.nargs,
                'required': argument.required,
                'action': argument.action || 'store',
                'help': argument.help,
                'choices': argument.choices || undefined
            });
        });
    });

    module.exports = {
        parser: parser,
        modules: modules
    };
}());