/*jslint node:true*/
/*global describe,before,it,after*/

(function () {

    'use strict';

    var expect = require('expect.js'),
        check  = require('../lib/testcases'),
        perl = require('../lib/perl'),
        sinon = require('sinon'),
        path = require('path'),
        stub;

    describe('Running testcases.js', function () {

        before(function () {
            stub = sinon.stub(perl, 'get');

            stub.withArgs('cartridges').yields(null, [
                'PARENT/CartridgeA',
                'PARENT/CartridgeB',
                'PARENT/CartridgeD',
                'PARENT/CartridgeE'
            ]);

            stub.withArgs('env', ['cartridges']).yields(null, {cartridges: path.join(__dirname, 'fs/cartridges')});
        });

        it('should check for existence of testcases and fail (single cartridge provided)', function (callback) {
            check('PARENT/CartridgeA', function (error) {
                expect(error).to.be('\n\u001b[31m\t[X] \u001b[39mMissing test case for \u001b[36mparent/cartridgea/myModuleWithoutTestcase.js\u001b[39m\n' +
                                    '\n==> We have \u001b[31m1\u001b[39m missing test cases | 2 modules checked | \u001b[31m50\u001b[39m percent coverage.');
                // 1 missing test case, 2 modules checked.
                callback();
            });
        });

        it('should fail to find provided cartridge', function (callback) {
            check('This_does_not_exist', function (error) {
                expect(error).to.be('Cartridge This_does_not_exist contains no JavaScript!');
                callback();
            });
        });

        it('should check for existence of testcases and pass (single cartridge provided)', function (callback) {
            check('PARENT/CartridgeB', function (error) {
                expect(error).to.be(undefined);
                callback();
            });
        });

        it('should check for existence of testcases (all cartridges)', function (callback) {
            check(undefined, function (error) {
                expect(error).to.be('\n\u001b[31m\t[X] \u001b[39mMissing test case for \u001b[36mparent/cartridgea/myModuleWithoutTestcase.js\u001b[39m' +
                                    '\n\u001b[31m\t[X] \u001b[39mMissing test case for \u001b[36mparent/cartridged/myThirdModuleWithoutTestcase.js\u001b[39m\n' +
                                    '\n==> We have \u001b[35m2\u001b[39m missing test cases | 5 modules checked | \u001b[35m60\u001b[39m percent coverage.');
                // 2 missing test cases, 5 modules checked.
                callback();
            });
        });

        after(function () {
            stub.restore();
        });

    });

}());
